/***************************************************************************
 *   Copyright (C) 2006 by Ken Werner                                      *
 *   ken.werner@web.de                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef DEFAULTSOURCE_H
#define DEFAULTSOURCE_H

#include "source.h"
#include "defaultsourcePrefs.h"
#include <qfile.h>
#include <qtimer.h>

class QLabel;

/**
 * DefaultSource is a simple Source that reads its value from a file and shows it on a Label
 * @author Ken Werner
 */
class DefaultSource : public Source {
	Q_OBJECT //macro which activates signals and slots (moc)
public:
	/**
	 * Creates a new DefaultSource from the given File
	 */
	DefaultSource(QWidget* inParent, const QFile& inSourceFile);

	/**
	 * Returns the Label of this source that is displayed in the kicker
	 */
	QWidget* getWidget();

	/**
	 * fills the prefs gui with appropriate values
	 */
	virtual void updatePrefsGUI();

protected slots:

	/**
	 * Applies the prefs
	 */
	virtual void applyPrefs();

	/**
	 * Saves the prefs (implicit apply)
	 */
	virtual void savePrefs(KConfig* inKConfig);

	/**
	 * Loads the prefs
	 */
	virtual void loadPrefs(KConfig* inKConfig);

	/**
	 * Updates the Label triggered by the timer
	 */
	void updateValues();

protected:
	/**
	 * This method can be overridden in sub classes to add specific preference panels
	 */
	virtual QWidget* addPrefs(QWidget* inParent);

	/**
	 * Returns path this source
	 */
	virtual QString getPath() const;

	/**
	 * Translates a given frequency in KHz to a human readable string
	 */
	QString KHzinHumanReadable( uint value ) const;

	/**
	 * Translates degree Celsius to degree Fahrenheit
	 */
	int celsiusToFahrenheit(int inCelsius) const;

	/**
	 * Returns inValue rounded to inDigits
	 */
	double round(double inValue, int inDigits=0) const;

	/**
	 * Displays the content of that source
	 */
	QLabel* mLabel;

	/**
	 * The file from which the value is read
	 */
	mutable QFile mSourceFile;

	/**
	 * The refresh timer of that source
	 * used for updating the label
	 */
	QTimer* mRefreshTimer;

private:
	DefaultSourcePrefs* mDefaultSourcePrefs;
};
#endif //DEFAULTSOURCE_H
