/***************************************************************************
 *   Copyright (C) 2006 by Ken Werner                                      *
 *   ken.werner@web.de                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "i2cfansrc.h"
#include <qtextstream.h> 
#include <klocale.h>
#include <kglobal.h>
#include <qdir.h>

I2CFanSrc::I2CFanSrc(QWidget* inParent, const QFile& inSourceFile, unsigned int inIndex):
		DefaultSource(inParent, inSourceFile){
	//mName = "I2C " + inSourceFile.name()[inSourceFile.name().length() - 7];
	mID = "i2cFan" + QString::number(inIndex);
	mName = mID;
	mDescription = "This source is provided by " +  inSourceFile.name();
}

I2CFanSrc::~I2CFanSrc(){
}

std::list<Source*>I2CFanSrc::createInstances(QWidget* inParent){
	std::list<Source*> list;
	// /sys/bus/i2c/devices/*/fan*_input
	QDir d("/sys/bus/i2c/devices/");
	QDir subd;
	if ( d.exists() ){
		unsigned int index = 1;
		d.setFilter(QDir::Dirs);
		d.setSorting(QDir::Name);
		for ( unsigned int i = 0; i < d.count(); i++ ){
			if((d[i] != ".") && (d[i] != "..")){
				subd = d.canonicalPath() + "/" + d[i];
				subd.setFilter(QDir::Files);
				subd.setSorting(QDir::Name);
				for ( unsigned int j = 0; j < subd.count(); j++ ){ 
					if((subd[j] != ".") && (subd[j] != "..") && (QDir::match(subd.canonicalPath() + "/fan*_input", subd.canonicalPath() + "/" + subd[j]))){
						QFile i2cFile(subd.canonicalPath() + "/" + subd[j]);
						if(i2cFile.open(IO_ReadOnly)){
							QTextStream textStream( &i2cFile );
							QString s = textStream.readLine();
							i2cFile.close();
							if(!s.startsWith("-")){
								list.push_back(new I2CFanSrc(inParent, i2cFile, index));
								index++;
							}
						}
					}
				}
			}
		}
	}
	return list;
}
QString I2CFanSrc::getValue() const{
	QString s = "n/a";
	if(mSourceFile.open(IO_ReadOnly)){
		QTextStream textStream( &mSourceFile );
		s = textStream.readLine().stripWhiteSpace();
		mSourceFile.close();
		s.append(" rpm");
	}
	return s;
}
